@@ -3,7 +3,7 @@ source("../object-inheritance.r", chdir = TRUE)
 Observable <- Object$clone()$do({
   .name <- "Observable"
   listeners <- list()
-  add_listener <- function(f, name = digest(f)) {
+  add_listener <- function(f, name = digest::digest(f)) {
     self$listeners[[name]] <- f
   }
 
